# JuMonC-LogParser

This plugin for JuMonC serves two functions, one being a general log parser plugin to extend JuMonC's functionality and on the other side to serve as a blueprint to develop plugins.

Therefore the documentation is split, for the actual usage of this plugin see this [README](JuMonC_LogParser/README.md).

Explanations for your own plugin documentation can be found [here](PLUGIN_DEV.md).
